# -*- coding: utf-8 -*-

"""
Scalix Installer
VERSION 0.11.5.1

Copyright (C) 2009 Rene Hadler
rene.hadler@aon.at

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

import os, re, sys, socket

from scalix_install_deb_11_1_0 import *
from scalix_install_deb_11_2_0 import *
from scalix_install_deb_11_3_0 import *
from scalix_install_deb_11_4_0 import *
from scalix_install_deb_11_4_1 import *
from scalix_install_deb_11_4_2 import *
from scalix_install_deb_11_4_3 import *
from scalix_install_deb_11_4_5 import *

from scalix_install_lib import i18n

i = i18n()
_ = i.get

class sx_install:
    
    PATH = PATH_UNPACK = PATH_SX_PKG = LANG = ""
    EXE_TAR = EXE_DPKG = EXE_DIR = EXE_APTGET = EXE_SH = EXE_WGET = ""
    HOSTNAME = FQDN = IP = SYS_DIST = ""
    SX_PKG = SX_VERSION = SX_PKG_TAR = SX_INSTANCE = ""
    SX_BIN = "/opt/scalix/bin/"
    SX_UI_DOMAIN = SX_UI_COMPANY = SX_UI_PASSWORD = SX_UI_JRAM = ""
    
    def __init__(self):
        print "Scalix-Installer 0.11.5.1 Copyright (C) 2008  Rene Hadler rene.hadler@aon.at"
        print "This program comes with ABSOLUTELY NO WARRANTY."
        print "This is free software, and you are welcome to redistribute it"
        print "under certain conditions."
        print "See gpl-3.0.txt for all details."
        print ""
        
        print _("WELCOME1")
        print _("WELCOME2")
        print ""

        print _("CHECK_CONFIG")
        self._check_env()
        self._log_r()
        
        print ""
        print _("CHECK_TOOLS")
        self._check_required_tools()
        
        print ""
        print _("CHECK_CONFIG_CONTINUE")
        input = raw_input(_("INPUT_Y_N") + " ")
        
        if input == "n": self._abort(_("INSTALLATION_ABORTED"))
        
        print ""
        print _("CREATE_SX_ENVIRONMENT")
        self._unpackPkg()
        
        print ""
        print _("SX_INSTALLATION")
        if self.SX_VERSION == "11.1.0":
            sx_install_11_1_0(self)
        elif self.SX_VERSION == "11.2.0":
            sx_install_11_2_0(self)
        elif self.SX_VERSION == "11.3.0":
            sx_install_11_3_0(self)
        elif self.SX_VERSION == "11.4.0":
            sx_install_11_4_0(self)
        elif self.SX_VERSION == "11.4.1":
            sx_install_11_4_1(self)
        elif self.SX_VERSION == "11.4.2":
            sx_install_11_4_2(self)
        elif self.SX_VERSION == "11.4.3":
            sx_install_11_4_3(self)
        elif self.SX_VERSION == "11.4.5":
            sx_install_11_4_5(self)
        else:
            self._abort(_("SX_INSTALLATION_BAD_VERSION"))
        
    def _check_env(self):
        # Check if installer is executed as root
        user = self._cmd("whoami")[0].replace("\n", "")
        if user == "root": print "  " + _("CHECK_CONFIG_USER_OK") + " (" + user + ")"
        else:
            print "  " + _("CHECK_CONFIG_BAD_USER") + " (" + user + ")"
            self._abort(_("CHECK_CONFIG_BAD_USER_MSG"))
            
        # Program path
        path = self._cmd("pwd")[0].replace("\n", "")
        self.PATH = path + "/"
        self.PATH_UNPACK = self.PATH + "tmp/"
        print "  " + _("CHECK_CONFIG_PATH_OK") + " (" + self.PATH + ")"
            
        # Hostname/FQDN right?
        hostname = self._cmd("hostname")[0].replace("\n", "")
        dist = self._cmd("cat /etc/issue")[0].replace("\n", "").replace("\l", "")
        fqdn = self._cmd("hostname --fqdn")[0].replace("\n", "")
        
        try:
            ip = self._cmd("cat /etc/hosts | grep " + hostname)[0].replace("\n", "").split(" ")[0].split("\t")[0]
            ipfqdn = self._cmd("cat /etc/hosts | grep " + fqdn)[0].replace("\n", "").split(" ")[0].split("\t")[0]
        except IndexError:
            localhostname, localaliaslist, localipaddrlist = socket.gethostbyaddr(socket.gethostname())
            ip = localipaddrlist[0]
            ipfqdn = ip
        
        if dist != "": 
            print "  " + _("CHECK_CONFIG_DIST_OK") + " (" + dist + ")"
            self.SYS_DIST = dist
        else:
            print "  " + _("CHECK_CONFIG_BAD_DIST") + " (" + dist + ")"
            self._abort(_("CHECK_CONFIG_BAD_DIST_MSG"))
            
        if re.match(".*Ubuntu 6\..*|.*Ubuntu 5\..*", self.SYS_DIST):
            self._abort(_("CHECK_CONFIG_OLD_DIST"))
        
        if hostname != "" and re.match("^[a-z0-9\-\.]*$", hostname): 
            print "  " + _("CHECK_CONFIG_HOSTNAME_OK") + " (" + hostname + ")"
            self.HOSTNAME = hostname
        else:
            print "  " + _("CHECK_CONFIG_BAD_HOSTNAME") + " (" + hostname + ")"
            self._configure_dns()
            self._abort(_("INSTALLATION_RESTART"))
            
        if fqdn != "" and re.match("^[a-z0-9\-]*\.([a-z0-9\-]*\.)*[a-z0-9\-]*$", fqdn): 
            print "  FQDN                -> OK (" + fqdn + ")"
            self.FQDN = fqdn
        else:
            print "  FQDN                -> Nicht OK (" + fqdn + ")"
            self._configure_dns()
            self._abort(_("INSTALLATION_RESTART"))
            
        if ip != "" and re.match("^[0-9]*\.[0-9]*\.[0-9]*\.[0-9]*$", ip) and not re.match("^127\.[0-9]*\.[0-9]*\.[0-9]*$", ip): 
            print "  " + _("CHECK_CONFIG_IP2HOSTNAME_OK") + " (" + ip + ")"
            self.IP = ip
        else:
            print "  " + _("CHECK_CONFIG_BAD_IP2HOSTNAME") + " (" + ip + ")"
            self._configure_dns()
            self._abort(_("INSTALLATION_RESTART"))
            
        if ipfqdn != "" and re.match("^[0-9]*\.[0-9]*\.[0-9]*\.[0-9]*$", ipfqdn) and not re.match("^127\.[0-9]*\.[0-9]*\.[0-9]*$", ipfqdn) and ip == ipfqdn: print "  " + _("CHECK_CONFIG_IP2FQDN_OK") + " (" + ipfqdn + ")"
        else:
            print "  " + _("CHECK_CONFIG_BAD_IP2FQDN") + " (" + ipfqdn + ")"
            self._configure_dns()
            self._abort(_("INSTALLATION_RESTART"))
        
        # Check services
        try: chksmtp = self._cmd("netstat -anp | grep " + self.IP + ":25")[0].replace("\n", "")
        except: chksmtp = ""
        if chksmtp == "": print "  " + _("CHECK_CONFIG_SMTP_OK")
        else:
            print "  " + _("CHECK_CONFIG_BAD_SMTP") + " (" + chksmtp + ")"
            self._abort(_("CHECK_CONFIG_BAD_SMTP_MSG"))
            
        try: chkpop = self._cmd("netstat -anp | grep " + self.IP + ":110")[0].replace("\n", "")
        except: chkpop = ""
        if chkpop == "": print "  " + _("CHECK_CONFIG_POP_OK")
        else:
            print "  " + _("CHECK_CONFIG_BAD_POP") + " (" + chkpop + ")"
            self._abort(_("CHECK_CONFIG_BAD_POP_MSG"))
            
        try: chkimap = self._cmd("netstat -anp | grep " + self.IP + ":143")[0].replace("\n", "")
        except: chkimap = ""
        if chkimap == "": print "  " + _("CHECK_CONFIG_IMAP_OK")
        else:
            print "  " + _("CHECK_CONFIG_BAD_IMAP") + " (" + chkimap + ")"
            self.__abort(_("CHECK_CONFIG_BAD_IMAP_MSG"))
            
        try: chkldap = self._cmd("netstat -anp | grep " + self.IP + ":389")[0].replace("\n", "")
        except: chkldap = ""
        if chkldap == "": print "  " + _("CHECK_CONFIG_LDAP_OK")
        else:
            print "  " + _("CHECK_CONFIG_BAD_LDAP") + " (" + chkldap + ")"
            self._abort(_("CHECK_CONFIG_BAD_LDAP_MSG"))
        
    def _check_required_tools(self):
        # TAR
        tar = self._gPFS("tar")
        if tar:
            print "  " + _("CHECK_TOOLS_TAR_OK") + " (" + tar + ")"
            self.EXE_TAR = tar
        else: 
            print "  " + _("CHECK_TOOLS_BAD_TAR")
            self._abort(_("CHECK_TOOLS_BAD_TAR_MSG"))
            
        # DPKG
        dpkg = self._gPFS("dpkg")
        if dpkg:
            print "  " + _("CHECK_TOOLS_DPKG_OK") + " (" + dpkg + ")"
            self.EXE_DPKG = dpkg
        else: 
            print "  " + _("CHECK_TOOLS_BAD_DPKG")
            self._abort(_("CHECK_TOOLS_BAD_DPKG_MSG"))
            
        # DIR
        dir = self._gPFS("dir")
        if dir:
            print "  " + _("CHECK_TOOLS_DIR_OK") + " (" + dir + ")"
            self.EXE_DIR = dir
        else: 
            print "  " + _("CHECK_TOOLS_BAD_DIR")
            self._abort(_("CHECK_TOOLS_BAD_DIR_MSG"))
            
        # APT-GET
        aptget = self._gPFS("apt-get")
        if aptget:
            print "  " + _("CHECK_TOOLS_APTGET_OK") + " (" + aptget + ")"
            self.EXE_APTGET = aptget
        else: 
            print "  " + _("CHECK_TOOLS_BAD_APTGET")
            self._abort(_("CHECK_TOOLS_BAD_APTGET_MSG"))
            
        # SH
        aptget = self._gPFS("sh")
        if aptget:
            print "  " + _("CHECK_TOOLS_SH_OK") + " (" + aptget + ")"
            self.EXE_SH = aptget
        else: 
            print "  " + _("CHECK_TOOLS_BAD_SH")
            self._abort(_("CHECK_TOOLS_BAD_SH_MSG"))
            
        # WGET
        aptget = self._gPFS("wget")
        if aptget:
            print "  " + _("CHECK_TOOLS_WGET_OK") + " (" + aptget + ")"
            self.EXE_WGET = aptget
        else: 
            print "  " + _("CHECK_TOOLS_BAD_WGET")
            self._abort(_("CHECK_TOOLS_BAD_WGET_MSG"))
            
        # Scalix Package available?
        for f in os.listdir(self.PATH):
            if self._fe(self.PATH + f):
                if re.match("^scalix.*(.tgz|.bin)$", f):
                    self.SX_PKG = f
                    break
                
        try: self.SX_VERSION = self.SX_PKG.split("-")[1]
        except: self.SX_VERSION = "unknown"
        
        if self.SX_PKG != "": print "  " + _("CHECK_TOOLS_SXPKG_OK") + " (" + self.SX_PKG + ")"
        else:
            print "  " + _("CHECK_TOOLS_BAD_SXPKG")
            self._abort(_("CHECK_TOOLS_BAD_SXPKG_MSG"))
            
        if self.SX_VERSION != "" and re.match("[0-9]*\.[0-9]*\.[0-9]*", self.SX_VERSION): print "  " + _("CHECK_TOOLS_SXVERSION_OK") + " (" + self.SX_VERSION + ")"
        else:
            print "  " + _("CHECK_TOOLS_BAD_SXVERSION")
            self._abort(_("CHECK_TOOLS_BAD_SXVERSION_MSG"))
    
        if self.SX_VERSION == "11.4.1":
            self.SX_PKG_TAR = "scalix-debian-" + self.SX_VERSION + "-U1-GA"
        else:
            self.SX_PKG_TAR = "scalix-debian-" + self.SX_VERSION + "-GA"
        self.PATH_SX_PKG = self.PATH_UNPACK + self.SX_PKG_TAR + "/"
    
    def _unpackPkg(self):
        if re.match(".*Ubuntu.*", self.SYS_DIST):
            print "  " + _("UNPACK_SX_FIX_UBUNTU_SH")
            os.system("ln -sf /bin/bash /bin/sh")
            
        print "  " + _("UNPACK_SX_REPLACE_SOURCES")
        if re.match(".*Ubuntu 7\.04.*", self.SYS_DIST):
            fp = open("/etc/apt/sources.list", "w")
            fp.write("deb http://de.archive.ubuntu.com/ubuntu/ feisty main restricted multiverse universe\n")
            fp.write("deb http://de.archive.ubuntu.com/ubuntu/ feisty-updates main restricted multiverse universe\n")
            fp.write("deb http://de.archive.ubuntu.com/ubuntu/ feisty-proposed restricted main multiverse universe\n")
            fp.write("deb http://security.ubuntu.com/ubuntu/ feisty-security restricted main multiverse universe\n")
            fp.close()
        elif re.match(".*Ubuntu 7\.10.*", self.SYS_DIST):
            fp = open("/etc/apt/sources.list", "w")
            fp.write("deb http://de.archive.ubuntu.com/ubuntu/ gutsy main restricted multiverse universe\n")
            fp.write("deb http://de.archive.ubuntu.com/ubuntu/ gutsy-updates main restricted multiverse universe\n")
            fp.write("deb http://de.archive.ubuntu.com/ubuntu/ gutsy-proposed restricted main multiverse universe\n")
            fp.write("deb http://security.ubuntu.com/ubuntu/ gutsy-security restricted main multiverse universe\n")
            fp.close()
        elif re.match(".*Ubuntu 8\.04.*", self.SYS_DIST):
            fp = open("/etc/apt/sources.list", "w")
            fp.write("deb http://de.archive.ubuntu.com/ubuntu/ hardy main restricted multiverse universe\n")
            fp.write("deb http://de.archive.ubuntu.com/ubuntu/ hardy-updates main restricted multiverse universe\n")
            fp.write("deb http://de.archive.ubuntu.com/ubuntu/ hardy-proposed restricted main multiverse universe\n")
            fp.write("deb http://security.ubuntu.com/ubuntu/ hardy-security restricted main multiverse universe\n")
            fp.close()
        elif re.match(".*Debian GNU/Linux 5\..*", self.SYS_DIST):
            fp = open("/etc/apt/sources.list", "w")
            fp.write("deb http://debian.inode.at/debian lenny main\n")
            fp.write("deb http://debian.inode.at/debian lenny non-free\n")
            fp.write("deb http://debian.inode.at/debian lenny contrib\n")
            fp.write("deb http://security.debian.org/ lenny/updates main contrib non-free")
            fp.close()
        elif re.match(".*Debian GNU/Linux 4\..*", self.SYS_DIST):
            fp = open("/etc/apt/sources.list", "w")
            fp.write("deb http://debian.inode.at/debian etch main\n")
            fp.write("deb http://debian.inode.at/debian etch non-free\n")
            fp.write("deb http://debian.inode.at/debian etch contrib\n")
            fp.write("deb http://security.debian.org/ etch/updates main contrib non-free")
            fp.close()
        
        print "  " + _("UNPACK_SX_UPDATE_SOURCES")
        inst_out = self._cmd(self.EXE_APTGET + " update")
        for line in inst_out:
            self._log(line)
        
        if self._de(self.PATH_UNPACK):
            self._cmd("rm -r " + self.PATH_UNPACK + "*")
            print "  " + _("UNPACK_SX_EXISTS")
        else:
            os.mkdir(self.PATH_UNPACK)
            print "  " + _("UNPACK_SX_SUCESS")
            
        if self.SX_VERSION == "11.3.0" or self.SX_VERSION == "11.4.0" or self.SX_VERSION == "11.4.1" or self.SX_VERSION == "11.4.2" or self.SX_VERSION == "11.4.3" or self.SX_VERSION == "11.4.5":
            print "  " + _("UNPACK_SX_11_3_0_NOTICE_1")
            print "  " + _("UNPACK_SX_11_3_0_NOTICE_2")
            print "  " + _("UNPACK_SX_11_3_0_NOTICE_3")
            print "  " + _("UNPACK_SX_11_3_0_NOTICE_4")
            print "  " + _("UNPACK_SX_11_3_0_NOTICE_5")
            input = raw_input(_("UNPACK_SX_11_3_0_NOTICE_CONTINUE") + " ")
            
            os.system(self.EXE_SH + " " + self.PATH + self.SX_PKG)
            self.PATH_SX_PKG = self.PATH + self.SX_PKG_TAR + "/"
        else:
            self._cmd(self.EXE_TAR + " xfz " + self.SX_PKG + " -C " + self.PATH_UNPACK)
        
        print "  " + _("UNPACK_SX_UNPACK_OK")
        
    def _configure_dns(self):
        print "  " + _("CONFIGURE_DNS_NOTICE")
        print "  " + _("INSTALLATION_CTRL_C")
        hn =   raw_input("  Hostname (" + _("CONFIGURE_DNS_LOWER") + "!) : ")
        fqdn = raw_input("  FQDN (Hostname + Domain)    : ")
        ip =   raw_input("  IP                          : ")
        
        fp = open("/etc/hosts", "w")
        fp.write("127.0.0.1           localhost\n")
        fp.write(ip + "               " + fqdn + " " + hn)
        fp.close()
        
        fp = open("/etc/hostname", "w")
        fp.write(hn)
        fp.close()
        
        os.system("hostname " + hn)
        
    def _log(self, txt):
        fp = open(self.PATH + "install.log", "a")
        fp.write(txt)
        fp.close()
        
    def _log_r(self):
        if self._fe(self.PATH + "install.log"):
            os.remove(self.PATH + "install.log")
            
    def _log_c(self, text):
        rt = False
        fp = open(self.PATH + "install.log", "r")
        for line in fp.readlines():
            if re.match(".*" + text + ".*", line):
                rt = True
        fp.close()
                
        return rt
    
    def _cmd(self, cmd):
        pp = os.popen(cmd + " 2>&1")
        output = pp.readlines()
        pp.close()
        
        return output
    
    def _fe(self, file):
        if os.path.isfile(file):
            return True
        else:
            return False
        
    def _de(self, dir):
        if os.path.isdir(dir):
            return True
        else:
            return False
    
    def _gPFS(self, program):
        paths = os.environ['PATH'].split(":")
        for path in paths:
            if self._fe(path + "/" + program):
                return path + "/" + program
            
        return False
    
    def _abort(self, msg):
        if msg != "": print "\n" + _("INSTALLATION_ABORT") + ": " + msg
        else: print "\n" + _("INSTALLATION_ABORT")
        sys.exit()
        
if __name__ == '__main__':
    sx_install()