# -*- coding: utf-8 -*-

"""
Scalix Installer
VERSION 0.11.4.1

Copyright (C) 2008 Rene Hadler
rene.hadler@aon.at

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

import os, re, sys, time

from scalix_install_lib import *

class sx_install_11_1_0:
    
    PI_OBJ = None
    DEP_PKGS = "apache2 libglib2.0-0 libstdc++2.10-glibc2.2 libstdc++5 libxml2 libsasl2-modules libsasl2-gssapi-mit libfreetype6 sendmail elinks gawk w3m"
    DEP_PKGS_MAN = "sun-java5-jdk krb5-config krb5-doc krb5-user libkadm55 libkrb53 postgresql"
    
    def __init__(self, pi_obj):
        self.PI_OBJ = pi_obj
        
        print "  Beginne Installation für Scalix " + self.PI_OBJ.SX_VERSION
        
        print "  Installiere benötigte externe Pakete mit apt-get"
        self._inst_dep_pkgs()
        
        print "  PATH und JAVA_HOME werden angepasst"
        self._set_env_vars()
        
        print "  Installiere und initalisiere Scalix Main Package"
        self._setup_scalix_server()
        
        print "  Richte Default Werte für Scalix Server ein"
        self._configure_default_sx_server()
        
        print "  Richte Default Werte für Admin Benutzer ein"
        self._configure_default_sx_admin()
        
        print "  Tweake Konfiguration und starte Scalix Services"
        self._tweak_and_start_sx()
        
        print "  Installiere restliche Scalix Pakete"
        self._inst_more_stuff()
        
        print "  Konfiguriere Scalix-Tomcat"
        self._conf_sx_tomcat()
        
        print "  Konfiguriere Scalix-Postgres"
        self._conf_sx_postgres()
        
        print "  Konfiguriere Scalix-Web-Access"
        self._conf_sx_webacc()
        
        print "  Konfiguriere Scalix-Ubermanager"
        self._conf_sx_uberm()
        
        print "  Konfiguriere Scalix-RES"
        self._conf_sx_res()
        
        print "  Konfiguriere Scalix-Messaging-Services"
        self._conf_sx_messer()
        
        print "  Konfiguriere Scalix-Mobile"
        self._conf_sx_mobile()
        
        print "  Konfiguriere Scalix-Search-Index"
        self._conf_sx_search()
        
        print "  Installation abschließen"
        self._finish_inst()
        
    def _inst_dep_pkgs(self):
        print "--------------- APT-GET OUTPUT ---------------"
        print "Bitte warten..."
        if re.match(".*Ubuntu 7\.04.*", self.PI_OBJ.SYS_DIST) or re.match(".*Ubuntu 7\.10.*", self.PI_OBJ.SYS_DIST):
            self.DEP_PKGS_MAN = self.DEP_PKGS_MAN.replace("postgresql", "postgresql-8.1")
            
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_APTGET + " -q -y install " + self.DEP_PKGS)
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "third_party/libical/i386/libical*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
        print "------------- APT-GET OUTPUT EOF -------------"
            
        print "  Installiere sun-jdk/krb5 (Manuelle Eingaben nötig -> Enter drücken)"
        print "--------------- APT-GET OUTPUT ---------------"
        print "Bitte warten..."
        os.system(self.PI_OBJ.EXE_APTGET + " -qq -y install " + self.DEP_PKGS_MAN)
        print "------------- APT-GET OUTPUT EOF -------------"
            
        print "  Installation der externen Pakete abgeschlossen"
        
    def _set_env_vars(self):
        if self.PI_OBJ._fe("/etc/profile"):
            fo = fileobj("/etc/profile")
            fo.astrtvar(".*PATH=\"/usr/local/sbin.*", ":/opt/scalix/bin:/opt/scalix/diag")
            fo.astrtfile("export JAVA_HOME=\"/usr/lib/jvm/java-1.5.0-sun\"")
            fo.astrtfile("export JRE_HOME=\"/usr/lib/jvm/java-1.5.0-sun\"")
            fo.write_wb()
        else:
            self.PI_OBJ._abort("Datei /etc/profile konnte nicht gefunden werden")
            
        print "    Umgebunsvariablen werden neu geladen"
        os.system("source /etc/profile")
            
    def _setup_scalix_server(self):
        if not self.PI_OBJ._fe("/usr/lib/libcrypto.so.0.9.7"):
            print "    Symlink für libcrypto korrigieren"
            try: slcr = self.PI_OBJ._cmd("ln -s /usr/lib/libcrypto.so.0.9.8 /usr/lib/libcrypto.so.0.9.7")[0]
            except: slcr = ""
            if slcr == "": print "    Symlink für libcrypto korrigiert"
            else: 
                self.PI_OBJ._abort("Symlink für libcrypto konnte nicht korrigiert werden" + slcr)
                
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-server*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        print "    Umgebunsvariablen werden neu geladen"
        os.system("source /etc/profile")
            
        print "    Initalisiere Scalix Message Store"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "ommakeom")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        if self.PI_OBJ._log_c("ompatchom: Scalix Initialization Complete"):
            print "    Initalisierung erfolgreich"
        else:
            self.PI_OBJ._abort("Intialisierung fehlgeschlagen. Bitte Log prüfen.")
        
        inst = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DIR + " /var/opt/scalix/")[0].replace("\n", "")
        if inst == "":
            self.PI_OBJ._abort("Es konnte keine Instanz gefunden werden")
        else:
            self.PI_OBJ.SX_INSTANCE = inst
            
    def _configure_default_sx_server(self):
        input = ""
        print "    Es werden nun Default Werte für die Scalix Installation abgefragt."
        print "    Bitte verwenden Sie keine Sonderzeichen sondern nur  ASCII Zeichen:"
        while input == "":
            input = raw_input("Domainname: ")
            self.PI_OBJ.SX_UI_DOMAIN = input
        input = ""
        
        while input == "":
            input = raw_input("Mailknoten (Meistens Domainname ohne TLD Endung): ")
            self.PI_OBJ.SX_UI_COMPANY = input
        input = ""
        
        while input == "":
            input = raw_input("Max Java VRAM (Meistens die Hälfte des verbauten RAMs): ")
            self.PI_OBJ.SX_UI_JRAM = input
        input = ""
        
        while input == "":
            input = raw_input("Passwort: ")
            self.PI_OBJ.SX_UI_PASSWORD = input
        input = ""
        
        rule = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "sxconfig --set -t general.usrl_cn_rule='S, G'")[0].replace("\n", "")
        if not re.match(".*has been added or modified.*", rule):
            self.PI_OBJ._abort("Regel 1 konnte nicht angelegt werden")
            
        rule = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "sxconfig --set -t general.usrl_authid_rule='gs@'")[0].replace("\n", "")
        if not re.match(".*has been added or modified.*", rule):
            self.PI_OBJ._abort("Regel 2 konnte nicht angelegt werden")
        
        rule = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "sxconfig --set -t orniasys.name_part_1='\"C\" <G.S>' -t orniasys.domain_part_1='" + self.PI_OBJ.SX_UI_DOMAIN + "'")[0].replace("\n", "")
        if not re.match(".*has been added or modified.*", rule):
            self.PI_OBJ._abort("Regel 3 konnte nicht angelegt werden")
            
        self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omaddmn -m " + self.PI_OBJ.SX_UI_COMPANY + " >> " + self.PI_OBJ.PATH + "install.log 2>&1")
        if not self.PI_OBJ._log_c(".*Mailnode added as primary mailnode.*"):
            self.PI_OBJ._abort("Default Mailknoten konnte nicht angelegt werden")
            
        startup = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omrc -n")
        for line in startup:
            self.PI_OBJ._log(line)
        
        if self.PI_OBJ._log_c("Directory Relay Server      Started"):
            print "    Scalix Services gestartet"
        else:
            self.PI_OBJ._abort("Scalix Services konnten nicht gestartet werden. Bitte Log prüfen.")
            
    def _configure_default_sx_admin(self):
        auc = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omaddu -n sxadmin/" + self.PI_OBJ.SX_UI_COMPANY + " --class limited -c admin -p " + self.PI_OBJ.SX_UI_PASSWORD + " sxadmin >> " + self.PI_OBJ.PATH + "install.log 2>&1")
        if not self.PI_OBJ._log_c(".*user was added successfully.*"): self.PI_OBJ._abort("Admin Benutzer konnte nicht angelegt werden")
        else: print "    Admin Benutzer angelegt"
        
        auc = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omconfenu -n \"sxadmin/" + self.PI_OBJ.SX_UI_COMPANY + "\"")[0].replace("\n", "")
        if not re.match(".*Notification user correctly configured.*", auc):
            self.PI_OBJ._abort("Admin Setting 1 konnte nicht angelegt werden")
            
        auc = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omlimit -u \"sxadmin/" + self.PI_OBJ.SX_UI_COMPANY + "\" -o -i 0 -m 0")[0].replace("\n", "")
        if not re.match(".*were modified successfully.*", auc):
            self.PI_OBJ._abort("Admin Setting 2 konnte nicht angelegt werden")
            
        auc = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omaddu -n sxqueryadmin/" + self.PI_OBJ.SX_UI_COMPANY + " --class limited -c admin -p " + self.PI_OBJ.SX_UI_PASSWORD + " sxqueryadmin@" + self.PI_OBJ.FQDN + " >> " + self.PI_OBJ.PATH + "install.log 2>&1")
        if not self.PI_OBJ._log_c(".*user was added successfully.*"): self.PI_OBJ._abort("LDAP Admin Benutzer konnte nicht angelegt werden")
        else: print "    LDAP Admin Benutzer angelegt"
        
        auc = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omaddpdl -l ScalixUserAdmins/" + self.PI_OBJ.SX_UI_COMPANY)[0].replace("\n", "")
        if not re.match(".*list was added successfully.*", auc):
            self.PI_OBJ._abort("Group Set 1 konnte nicht angelegt werden")
            
        auc = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omaddpdl -l ScalixUserAttributesAdmins/" + self.PI_OBJ.SX_UI_COMPANY)[0].replace("\n", "")
        if not re.match(".*list was added successfully.*", auc):
            self.PI_OBJ._abort("Group Set 2 konnte nicht angelegt werden")
            
        auc = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omaddpdl -l ScalixGroupAdmins/" + self.PI_OBJ.SX_UI_COMPANY)[0].replace("\n", "")
        if not re.match(".*list was added successfully.*", auc):
            self.PI_OBJ._abort("Group Set 3 konnte nicht angelegt werden")
            
        auc = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omaddpdl -l ScalixAdmins/" + self.PI_OBJ.SX_UI_COMPANY)[0].replace("\n", "")
        if not re.match(".*list was added successfully.*", auc):
            self.PI_OBJ._abort("Group Set 4 konnte nicht angelegt werden")
            
        print "    Admin Gruppen angelegt"
        
    def _tweak_and_start_sx(self):
        ftt = "/var/opt/scalix/" + self.PI_OBJ.SX_INSTANCE + "/s/sys/general.cfg"
        if self.PI_OBJ._fe(ftt):
            fo = fileobj(ftt)
            fo.astrtfile("CDA_USE_CHANGE_LOG=TRUE")
            fo.astrtfile("IMAP_CONNECTION_LIMIT=500")
            fo.astrtfile("IMAP_CONNRATE_LIMIT=10")
            fo.astrtfile("IMAP_IDLE_TIMEOUT=31")
            fo.astrtfile("LD_CREATE_MESSAGE_STORE=TRUE")
            fo.astrtfile("UAL_SIGNON_ALIAS=YES")
            fo.astrtfile("UAL_SIGNON_ALIAS_CONFIG=SYS")
            fo.astrtfile("UAL_USE_SIGNON_ALIAS=FALSE")
            fo.write_wb()
        else:
            self.PI_OBJ._abort("Datei " + ftt + " konnte nicht gefunden werden")
            
        auc = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omon -s all")[0].replace("\n", "")
        if not re.match(".*Enabling 14 subsystem.*", auc):
            self.PI_OBJ._abort("Scalix Services konnten nicht gestartet werden")
            
        print "    Konfiguration getweakt und Services gestartet"
        
    def _inst_more_stuff(self):
        print "    Installiere Scalix-Tomcat-Connector"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-tomcat-connector*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        print "    Installiere Scalix-Tomcat"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-tomcat_*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        print "    Installiere Scalix-Mobile"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-mobile*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        print "    Installiere Scalix-Platform"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-platform*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        print "    Installiere Scalix-Postgres"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-postgres*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
        
        print "    Installiere Scalix-RES"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-res*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        print "    Installiere Scalix-SAC"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-sac*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        print "    Installiere Scalix-SIS"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-sis*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        print "    Installiere Scalix-SWA"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-swa*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        print "    Installiere Scalix-Text-Extractors"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-text-extractors*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
    def _conf_sx_tomcat(self):
        fo = fileobj("/etc/opt/scalix-tomcat/scalix-tomcat.conf")
        fo.mstrtvar("JAVA_OPTS.*", "-server -Xms" + self.PI_OBJ.SX_UI_JRAM + "m -Xmx" + self.PI_OBJ.SX_UI_JRAM + "m")
        fo.write_wb()
        print "    OK"
        
    def _conf_sx_postgres(self):
        os.system("/opt/scalix-postgres/bin/sxpsql-init")
        
        auc = self.PI_OBJ._cmd("/opt/scalix-postgres/bin/sxpsql-setpwd " + self.PI_OBJ.SX_UI_PASSWORD)[0].replace("\n", "")
        if not re.match(".*ALTER USER.*|.*ALTER ROLE.*", auc):
            self.PI_OBJ._abort("Postgres Passwort konnte nicht gesetzt werden.")
            
        os.system("/opt/scalix-postgres/bin/sxpsql-whitelist " + self.PI_OBJ.IP)
        print "    OK"
        
    def _conf_sx_webacc(self):
        ftt = "/var/opt/scalix/" + self.PI_OBJ.SX_INSTANCE + "/webmail/swa.properties"
        if self.PI_OBJ._fe(ftt):
            fo = fileobj(ftt)
            fo.mstrtvarwoc("swa\.email\.domain.*", self.PI_OBJ.SX_UI_DOMAIN)
            fo.mstrtvarwoc("swa\.email\.imapServer.*", self.PI_OBJ.FQDN)
            fo.mstrtvarwoc("swa\.email\.smtpServer.*", self.PI_OBJ.FQDN)
            
            fo.mstrtvarwoc("swa\.ldap\.1\.server.*", self.PI_OBJ.FQDN)
            fo.mstrtvarwoc("swa\.ldap\.1\.port.*", "389")
            
            fo.mstrtvarwoc("swa\.ldap\.2\.server.*", self.PI_OBJ.FQDN)
            fo.mstrtvarwoc("swa\.ldap\.2\.port.*", "389")
            
            fo.mstrtvarwoc("swa\.platform\.url.*", "http://" + self.PI_OBJ.FQDN + "/api")
            fo.mstrtvarwoc("swa\.platform\.url\.format.*", "")
            fo.mstrtvarwoc("swa\.platform\.enabled.*", "true")
            fo.mstrtvarwoc("swa\.soap\.soapRequestTimeout.*", "60")
            fo.write_wb()
        else:
            self.PI_OBJ._abort("Datei " + ftt + " konnte nicht gefunden werden")
            
        print "    OK"
        
    def _conf_sx_uberm(self):
        ftt = "/var/opt/scalix/" + self.PI_OBJ.SX_INSTANCE + "/caa/scalix.res/config/ubermanager.properties"
        if self.PI_OBJ._fe(ftt):
            fo = fileobj(ftt)
            fo.mstrtvarwoc("ubermanager\.query\.server.*", self.PI_OBJ.FQDN)
            fo.mstrtvarwoc("ubermanager\.kerberos\.mode.*", "false")
            fo.mstrtvarwoc("ubermanager\.kerberos\.principalName.*", "")
            fo.mstrtvarwoc("ubermanager\.kerberos\.kdc.*", "")
            fo.mstrtvarwoc("ubermanager\.kerberos\.realm.*", "")
            
            fo.mstrtvarwoc("ubermanager\.console\.externalAuth.*", "false")
            fo.mstrtvarwoc("ubermanager\.console\.allowExternalAuthChoice.*", "false")
            fo.mstrtvarwoc("ubermanager\.console\.maxListSize.*", "100")
            fo.mstrtvarwoc("ubermanager\.console\.localDomains.*", self.PI_OBJ.SX_UI_DOMAIN)
            fo.mstrtvarwoc("ubermanager\.console\.authDomains.*", "")
            fo.mstrtvarwoc("ubermanager\.console\.modifyExternalSyncedAuthId.*", "false")
            
            fo.mstrtvarwoc("ubermanager\.query\.server\.port.*", "389")
            fo.mstrtvarwoc("ubermanager\.configured.*", "true")
            fo.mstrtvarwoc("ubermanager\.version.*", self.PI_OBJ.SX_VERSION)
            fo.write_wb()
        else:
            self.PI_OBJ._abort("Datei " + ftt + " konnte nicht gefunden werden")
            
        ftc = "/var/opt/scalix/" + self.PI_OBJ.SX_INSTANCE + "/caa/scalix.res/config/psdata"
        fp = open(ftc, "w")
        fp.write(self.PI_OBJ.SX_UI_PASSWORD)
        fp.close()
        
        os.chown(ftc, 0, 0)
        os.chmod(ftc, 0400)
            
        print "    OK"
        
    def _conf_sx_res(self):
        ftt = "/var/opt/scalix/" + self.PI_OBJ.SX_INSTANCE + "/res/config/res.properties"
        if self.PI_OBJ._fe(ftt):
            fo = fileobj(ftt)
            fo.mstrtvarwoc("res\.kerberos\.mode.*", "")
            fo.mstrtvarwoc("res\.kerberos\.kdc.*", "")
            fo.mstrtvarwoc("res\.kerberos\.realm.*", "")
            fo.mstrtvarwoc("res\.kerberos\.allowedclients.*", "ubermanager/" + self.PI_OBJ.FQDN)
            
            fo.mstrtvarwoc("res\.ubermanager\.host.*", self.PI_OBJ.FQDN)
            fo.mstrtvarwoc("res\.tomcat\.tcp\.port.*", "80")
            fo.mstrtvarwoc("res\.configured.*", "true")
            fo.mstrtvarwoc("res\.version.*", self.PI_OBJ.SX_VERSION)
            fo.write_wb()
        else:
            self.PI_OBJ._abort("Datei " + ftt + " konnte nicht gefunden werden")
            
        print "    OK"
        
    def _conf_sx_messer(self):
        ftt = "/var/opt/scalix/" + self.PI_OBJ.SX_INSTANCE + "/platform/platform.properties"
        if self.PI_OBJ._fe(ftt):
            fo = fileobj(ftt)
            fo.mstrtvarwoc("imap\.host.*", self.PI_OBJ.FQDN)
            fo.mstrtvarwoc("smtp\.host.*", self.PI_OBJ.FQDN)
            fo.mstrtvarwoc("ldap\.port.*", "389")
            fo.mstrtvarwoc("hibernate\.connection\.url.*", "jdbc:postgresql://" + self.PI_OBJ.FQDN + ":5733/scalix")
            fo.mstrtvarwoc("hibernate\.connection\.password.*", self.PI_OBJ.SX_UI_PASSWORD)
            fo.write_wb()
        else:
            self.PI_OBJ._abort("Datei " + ftt + " konnte nicht gefunden werden")
            
        print "    OK"
        
    def _conf_sx_mobile(self):
        ftt = "/var/opt/scalix/" + self.PI_OBJ.SX_INSTANCE + "/mobile/mobile.properties"
        if self.PI_OBJ._fe(ftt):
            fo = fileobj(ftt)
            fo.mstrtvarwoc("platform\.url.*", "http://" + self.PI_OBJ.FQDN + "/api")
            fo.write_wb()
        else:
            self.PI_OBJ._abort("Datei " + ftt + " konnte nicht gefunden werden")
            
        print "    OK"
        
    def _conf_sx_search(self):
        ftt = "/var/opt/scalix/" + self.PI_OBJ.SX_INSTANCE + "/sis/sis.properties"
        if self.PI_OBJ._fe(ftt):
            fo = fileobj(ftt)
            fo.mstrtvarwoc("index\.language.*", "German")
            fo.mstrtvarwoc("index\.client\.whitelist.*", self.PI_OBJ.IP)
            fo.mstrtvarwoc("search\.client\.whitelist.*", self.PI_OBJ.IP)
            fo.write_wb()
        else:
            self.PI_OBJ._abort("Datei " + ftt + " konnte nicht gefunden werden")
            
        print "    OK"
        
    def _finish_inst(self):
        time.sleep(5)
        print "    Restarting Tomcat"
        os.system("/etc/init.d/scalix-tomcat stop")
        time.sleep(3)
        os.system("/etc/init.d/scalix-tomcat start")
        
        print "    Kopiere Apache Config"
        os.system("ln -s /opt/scalix/global/httpd/scalix-web-client.conf /etc/apache2/conf.d")
        
        ftt = "/etc/apache2/mods-enabled/proxy.conf"
        if self.PI_OBJ._fe(ftt):
            fo = fileobj(ftt)
            fo.rstrtvarwoc(".*Deny from.*", "                Deny from none")
            fo.rstrtvarwoc(".*#Allow from \.exa.*", "                Allow from all")
            fo.write_wb()
        else:
            self.PI_OBJ._abort("Datei " + ftt + " konnte nicht gefunden werden")
        
        print "    Setze Java @ UTF-8"
        ftt = "/opt/scalix-tomcat/bin/setclasspath.sh"
        if self.PI_OBJ._fe(ftt):
            fo = fileobj(ftt)
            fo.astrtfile("export LC_ALL=de_DE.UTF-8")
            fo.astrtfile("export LANG=de_DE.UTF-8")
            fo.write_wb()
        else:
            self.PI_OBJ._abort("Datei " + ftt + " konnte nicht gefunden werden")
            
        print "    Restarting Apache"
        os.system("/etc/init.d/apache2 stop")
        time.sleep(3)
        os.system("/etc/init.d/apache2 start")
        
        print "    Installation abgeschlossen. Bitte Rechner neu starten."
        print "    ---------------------------------------"
        print "    Nach dem Neustart erreichen Sie:"
        print "    Das Admin Interface unter: http://" + self.PI_OBJ.IP + "/sac"
        print "    Das WebMail Interface unter: http://" + self.PI_OBJ.IP + "/webmail"
        print ""
        print "    Sie können sich im Admin Interface mit dem Benutzer 'sxadmin' und"
        print "    mit dem bei der Installation festgelegtem Passwort einloggen"
        print "    ---------------------------------------"