# -*- coding: utf-8 -*-

"""
Scalix Installer
VERSION 0.11.4.1

Copyright (C) 2008 Rene Hadler
rene.hadler@aon.at

English translation by David Bezemer
Suggestions and corrections can be mailed to:
themmai@gmail.com

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

import os, re, sys, time

from scalix_install_lib import *

i = i18n()
_ = i.get

class sx_install_11_4_1:
    
    PI_OBJ = None
    DEP_PKGS = "apache2 libglib2.0-0 libstdc++2.10-glibc2.2 libstdc++5 libxml2 libsasl2-modules libsasl2-gssapi-mit libfreetype6 elinks gawk w3m"
    DEP_PKGS_MAN = "sun-java5-jdk krb5-config krb5-doc krb5-user libkadm55 libkrb53 postgresql sendmail"
    
    def __init__(self, pi_obj):
        self.PI_OBJ = pi_obj
        
        print "  " + _("INST_MAIN_BEGIN") + " " + self.PI_OBJ.SX_VERSION
        
        print "  " + _("INST_MAIN_EXT_PKG")
        self._inst_dep_pkgs()
        
        print "  " + _("INST_MAIN_PATH")
        self._set_env_vars()
        
        print "  " + _("INST_MAIN_SX_INIT")
        self._setup_scalix_server()
        
        print "  " + _("INST_MAIN_SX_SETUP")
        self._configure_default_sx_server()
        
        print "  " + _("INST_MAIN_ADMIN_SETUP")
        self._configure_default_sx_admin()
        
        print "  " + _("INST_MAIN_SX_TWEAK_START")
        self._tweak_and_start_sx()
        
        print "  " + _("INST_MAIN_SX_OTHER")
        self._inst_more_stuff()
        
        print "  " + _("INST_MAIN_SX_TOMCAT")
        self._conf_sx_tomcat()
        
        print "  " + _("INST_MAIN_SX_POSTGRES")
        self._conf_sx_postgres()
        
        print "  " + _("INST_MAIN_SX_WEBA")
        self._conf_sx_webacc()
        
        print "  " + _("INST_MAIN_SX_UBER")
        self._conf_sx_uberm()
        
        print "  " + _("INST_MAIN_SX_RES")
        self._conf_sx_res()
        
        print "  " + _("INST_MAIN_SX_MESSERV")
        self._conf_sx_messer()
        
        print "  " + _("INST_MAIN_SX_MOBILE")
        self._conf_sx_mobile()
        
        print "  " + _("INST_MAIN_SX_SEARCH")
        self._conf_sx_search()
        
        print "  " + _("INST_MAIN_END")
        self._finish_inst()
        
    def _inst_dep_pkgs(self):
        print "--------------- " + _("APT_GET_OUTPUT") + " ---------------"
        print _("INST_EXT_PKG_WAIT")
        if re.match(".*Ubuntu 7\.04.*", self.PI_OBJ.SYS_DIST) or re.match(".*Ubuntu 7\.10.*", self.PI_OBJ.SYS_DIST):
            self.DEP_PKGS_MAN = self.DEP_PKGS_MAN.replace("postgresql", "postgresql-8.1")
            
        if re.match(".*Ubuntu 8\.04.*", self.PI_OBJ.SYS_DIST):
            self.DEP_PKGS = "apache2 elinks gawk gcc-3.3-base libfreetype6 libglib2.0-0 libsasl2 libsasl2-modules libsasl2-modules-gssapi-mit postgresql-client libstdc++5 libxml2 sendmail sendmail-cf w3m"
        
            inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_WGET + " --directory-prefix=" + self.PI_OBJ.PATH_SX_PKG + " http://http.us.debian.org/debian/pool/main/g/gcc-2.95/libstdc++2.10-glibc2.2_2.95.4-27_i386.deb")
            for line in inst_out:
                self.PI_OBJ._log(line)
                
            inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "libstdc++2.10-glibc2.2_2.95.4-27_i386.deb")
            for line in inst_out:
                self.PI_OBJ._log(line)
        
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_APTGET + " -q -y install " + self.DEP_PKGS)
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-libical*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-chardet*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
        print "------------- " + _("APT_GET_OUTPUT_EOF") + " -------------"
            
        print "  " + _("INST_EXT_PKG_JAVA_KRB")
        print "--------------- " + _("APT_GET_OUTPUT") + " ---------------"
        print _("INST_EXT_PKG_WAIT")
        os.system(self.PI_OBJ.EXE_APTGET + " -qq -y install " + self.DEP_PKGS_MAN)
        print "------------- " + _("APT_GET_OUTPUT_EOF") + " -------------"
            
        print "  " + _("INST_EXT_PKG_END")
        
    def _set_env_vars(self):
        if self.PI_OBJ._fe("/etc/profile"):
            fo = fileobj("/etc/profile")
            fo.astrtvar(".*PATH=\"/usr/local/sbin.*", ":/opt/scalix/bin:/opt/scalix/diag")
            fo.astrtfile("export JAVA_HOME=\"/usr/lib/jvm/java-1.5.0-sun\"")
            fo.astrtfile("export JRE_HOME=\"/usr/lib/jvm/java-1.5.0-sun\"")
            fo.write_wb()
        else:
            self.PI_OBJ._abort(_("INST_PATH_PROFILE_NFOUND"))
            
        print "    " + _("INST_PATH_ENV_RELOAD")
        os.system("source /etc/profile")
            
    def _setup_scalix_server(self):
        if not self.PI_OBJ._fe("/usr/lib/libcrypto.so.0.9.7"):
            print "    " + _("INST_SX_INIT_LIBCRY")
            try: slcr = self.PI_OBJ._cmd("ln -s /usr/lib/libcrypto.so.0.9.8 /usr/lib/libcrypto.so.0.9.7")[0]
            except: slcr = ""
            if slcr == "": print "    " + _("INST_SX_INIT_LIBCRY_OK")
            else: 
                self.PI_OBJ._abort(_("INST_SX_INIT_LIBCRY_FAILED") + slcr)
                
        if re.match(".*Ubuntu 8\.04.*", self.PI_OBJ.SYS_DIST):
            if not self.PI_OBJ._fe("/usr/lib/libldap_r.so.2"):
                print "    " + _("INST_SX_INIT_LIBLDAP")
                try: slcr = self.PI_OBJ._cmd("ln -s /usr/lib/libldap_r-2.4.so.2 /usr/lib/libldap_r.so.2")[0]
                except: slcr = ""
                if slcr == "": print "    " + _("INST_SX_INIT_LIBLDAP_OK")
                else: 
                    self.PI_OBJ._abort(_("INST_SX_INIT_LIBLDAP_FAILED") + slcr)
                    
            if not self.PI_OBJ._fe("/usr/lib/liblber.so.2"):
                print "    " + _("INST_SX_INIT_LIBLBER")
                try: slcr = self.PI_OBJ._cmd("ln -s /usr/lib/liblber-2.4.so.2 /usr/lib/liblber.so.2")[0]
                except: slcr = ""
                if slcr == "": print "    " + _("INST_SX_INIT_LIBLBER_OK")
                else: 
                    self.PI_OBJ._abort(_("INST_SX_INIT_LIBLBER_FAILED") + slcr)
        
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-server*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        print "    " + _("INST_PATH_ENV_RELOAD")
        os.system("source /etc/profile")
            
        print "    " + _("INST_SX_INIT_MSG_STORE")
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "ommakeom")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        if self.PI_OBJ._log_c("ompatchom: Scalix Initialization Complete"):
            print "    " + _("INST_SX_INIT_MSG_STORE_OK")
        else:
            self.PI_OBJ._abort(_("INST_SX_INIT_MSG_STORE_FAILED"))
        
        inst = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DIR + " /var/opt/scalix/")[0].replace("\n", "")
        if inst == "":
            self.PI_OBJ._abort(_("INST_SX_INIT_INST_NF"))
        else:
            self.PI_OBJ.SX_INSTANCE = inst
            
    def _configure_default_sx_server(self):
        input = ""
        print "    " + _("INST_SX_SETUP_INFO_1")
        print "    " + _("INST_SX_SETUP_INFO_2")
        while input == "":
            input = raw_input("Domain: ")
            self.PI_OBJ.SX_UI_DOMAIN = input
        input = ""
        
        while input == "":
            input = raw_input(_("INST_SX_SETUP_MAIL_NODE_NAME") + ": ")
            self.PI_OBJ.SX_UI_COMPANY = input
        input = ""
        
        while input == "":
            input = raw_input(_("INST_SX_SETUP_MAIL_JAVA_RAM") + ": ")
            self.PI_OBJ.SX_UI_JRAM = input
        input = ""
        
        while input == "":
            input = raw_input(_("INST_SX_SETUP_MAIL_PASSWORD") + ": ")
            self.PI_OBJ.SX_UI_PASSWORD = input
        input = ""
        
        rule = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "sxconfig --set -t general.usrl_cn_rule='S, G'")[0].replace("\n", "")
        if not re.match(".*has been added or modified.*", rule):
            self.PI_OBJ._abort(_("INST_SX_SETUP_RULE_1_FAILED"))
            
        rule = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "sxconfig --set -t general.usrl_authid_rule='gs@'")[0].replace("\n", "")
        if not re.match(".*has been added or modified.*", rule):
            self.PI_OBJ._abort(_("INST_SX_SETUP_RULE_2_FAILED"))
        
        rule = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "sxconfig --set -t orniasys.name_part_1='\"C\" <G.S>' -t orniasys.domain_part_1='" + self.PI_OBJ.SX_UI_DOMAIN + "'")[0].replace("\n", "")
        if not re.match(".*has been added or modified.*", rule):
            self.PI_OBJ._abort(_("INST_SX_SETUP_RULE_3_FAILED"))
            
        self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omaddmn -m " + self.PI_OBJ.SX_UI_COMPANY + " >> " + self.PI_OBJ.PATH + "install.log 2>&1")
        if not self.PI_OBJ._log_c(".*Mailnode added as primary mailnode.*"):
            self.PI_OBJ._abort(_("INST_SX_SETUP_MAIL_NODE_FAILED"))
            
        startup = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omrc -n")
        for line in startup:
            self.PI_OBJ._log(line)
        
        if self.PI_OBJ._log_c("Directory Relay Server      Started"):
            print "    " + _("INST_SX_SETUP_SERV_STARTED")
        else:
            self.PI_OBJ._abort(_("INST_SX_SETUP_SERV_NSTARTED"))
            
    def _configure_default_sx_admin(self):
        auc = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omaddu -n sxadmin/" + self.PI_OBJ.SX_UI_COMPANY + " --class limited -c admin -p " + self.PI_OBJ.SX_UI_PASSWORD + " sxadmin >> " + self.PI_OBJ.PATH + "install.log 2>&1")
        if not self.PI_OBJ._log_c(".*user was added successfully.*"): self.PI_OBJ._abort(_("INST_ADMIN_SETUP_USER_FAILED"))
        else: print "    " + _("INST_ADMIN_SETUP_USER_OK")
        
        auc = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omconfenu -n \"sxadmin/" + self.PI_OBJ.SX_UI_COMPANY + "\"")[0].replace("\n", "")
        if not re.match(".*Notification user correctly configured.*", auc):
            self.PI_OBJ._abort(_("INST_ADMIN_SETUP_SETT_1_FAILED"))
            
        auc = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omlimit -u \"sxadmin/" + self.PI_OBJ.SX_UI_COMPANY + "\" -o -i 0 -m 0")[0].replace("\n", "")
        if not re.match(".*were modified successfully.*", auc):
            self.PI_OBJ._abort(_("INST_ADMIN_SETUP_SETT_2_FAILED"))
            
        auc = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omaddu -n sxqueryadmin/" + self.PI_OBJ.SX_UI_COMPANY + " --class limited -c admin -p " + self.PI_OBJ.SX_UI_PASSWORD + " sxqueryadmin@" + self.PI_OBJ.FQDN + " >> " + self.PI_OBJ.PATH + "install.log 2>&1")
        if not self.PI_OBJ._log_c(".*user was added successfully.*"): self.PI_OBJ._abort(_("INST_ADMIN_SETUP_LDAPUSER_FAILED"))
        else: print "    " + _("INST_ADMIN_SETUP_LDAPUSER_OK")
        
        auc = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omaddpdl -l ScalixUserAdmins/" + self.PI_OBJ.SX_UI_COMPANY)[0].replace("\n", "")
        if not re.match(".*list was added successfully.*", auc):
            self.PI_OBJ._abort(_("INST_ADMIN_SETUP_GROUP_1_FAILED"))
            
        auc = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omaddpdl -l ScalixUserAttributesAdmins/" + self.PI_OBJ.SX_UI_COMPANY)[0].replace("\n", "")
        if not re.match(".*list was added successfully.*", auc):
            self.PI_OBJ._abort(_("INST_ADMIN_SETUP_GROUP_2_FAILED"))
            
        auc = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omaddpdl -l ScalixGroupAdmins/" + self.PI_OBJ.SX_UI_COMPANY)[0].replace("\n", "")
        if not re.match(".*list was added successfully.*", auc):
            self.PI_OBJ._abort(_("INST_ADMIN_SETUP_GROUP_3_FAILED"))
            
        auc = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omaddpdl -l ScalixAdmins/" + self.PI_OBJ.SX_UI_COMPANY)[0].replace("\n", "")
        if not re.match(".*list was added successfully.*", auc):
            self.PI_OBJ._abort(_("INST_ADMIN_SETUP_GROUP_4_FAILED"))
            
        print "    " + _("INST_ADMIN_SETUP_GROUP_SUCCESS")
        
    def _tweak_and_start_sx(self):
        ftt = "/var/opt/scalix/" + self.PI_OBJ.SX_INSTANCE + "/s/sys/general.cfg"
        if self.PI_OBJ._fe(ftt):
            fo = fileobj(ftt)
            fo.astrtfile("CDA_USE_CHANGE_LOG=TRUE")
            fo.astrtfile("IMAP_CONNECTION_LIMIT=500")
            fo.astrtfile("IMAP_CONNRATE_LIMIT=10")
            fo.astrtfile("IMAP_IDLE_TIMEOUT=31")
            fo.astrtfile("LD_CREATE_MESSAGE_STORE=TRUE")
            fo.astrtfile("UAL_SIGNON_ALIAS=YES")
            fo.astrtfile("UAL_SIGNON_ALIAS_CONFIG=SYS")
            fo.astrtfile("UAL_USE_SIGNON_ALIAS=FALSE")
            fo.write_wb()
        else:
            self.PI_OBJ._abort(_("STR_FILE") + ftt + _("STR_NOT_FOUND"))
            
        auc = self.PI_OBJ._cmd(self.PI_OBJ.SX_BIN + "omon -s all")[0].replace("\n", "")

        try: chksmtp = self.PI_OBJ._cmd("netstat -anp | grep " + self.PI_OBJ.IP + ":25")[0].replace("\n", "")
        except: chksmtp = ""
        if chksmtp == "": self.PI_OBJ._abort(_("INST_SX_SETUP_SERV_NSTARTED"))
            
        print "    " + _("INST_SX_TWEAK_START_SUCCESS")
        
    def _inst_more_stuff(self):
        print "    " + _("STR_INSTALL") + " Scalix-Tomcat-Connector"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-tomcat-connector*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        print "    " + _("STR_INSTALL") + " Scalix-Tomcat"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-tomcat_*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        print "    " + _("STR_INSTALL") + " Scalix-Mobile"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-mobile*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        print "    " + _("STR_INSTALL") + " Scalix-Platform"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-platform*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        print "    " + _("STR_INSTALL") + " Scalix-Postgres"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-postgres*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
        
        print "    " + _("STR_INSTALL") + " Scalix-RES"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-res*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        print "    " + _("STR_INSTALL") + " Scalix-SAC"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-sac*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        print "    " + _("STR_INSTALL") + " Scalix-SIS"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-sis*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        print "    " + _("STR_INSTALL") + " Scalix-SWA"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-swa*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
        print "    " + _("STR_INSTALL") + " Scalix-Text-Extractors"
        inst_out = self.PI_OBJ._cmd(self.PI_OBJ.EXE_DPKG + " -i " + self.PI_OBJ.PATH_SX_PKG + "software/scalix_server/scalix-text-extractors*.deb")
        for line in inst_out:
            self.PI_OBJ._log(line)
            
    def _conf_sx_tomcat(self):
        fo = fileobj("/etc/opt/scalix-tomcat/scalix-tomcat.conf")
        fo.mstrtvar("JAVA_OPTS.*", "-server -Xms" + self.PI_OBJ.SX_UI_JRAM + "m -Xmx" + self.PI_OBJ.SX_UI_JRAM + "m")
        fo.write_wb()
        print "    OK"
        
    def _conf_sx_postgres(self):
        os.system("/opt/scalix-postgres/bin/sxpsql-init")
        
        auc = self.PI_OBJ._cmd("/opt/scalix-postgres/bin/sxpsql-setpwd " + self.PI_OBJ.SX_UI_PASSWORD)[0].replace("\n", "")
        if not re.match(".*ALTER USER.*|.*ALTER ROLE.*", auc):
            self.PI_OBJ._abort(_("INST_SX_POSTGRES_SETPASS_FAILED"))
            
        os.system("/opt/scalix-postgres/bin/sxpsql-whitelist " + self.PI_OBJ.IP)
        print "    OK"
        
    def _conf_sx_webacc(self):
        ftt = "/var/opt/scalix/" + self.PI_OBJ.SX_INSTANCE + "/webmail/swa.properties"
        if self.PI_OBJ._fe(ftt):
            fo = fileobj(ftt)
            fo.mstrtvarwoc("swa\.email\.domain.*", self.PI_OBJ.SX_UI_DOMAIN)
            fo.mstrtvarwoc("swa\.email\.imapServer.*", self.PI_OBJ.FQDN)
            fo.mstrtvarwoc("swa\.email\.smtpServer.*", self.PI_OBJ.FQDN)
            
            fo.mstrtvarwoc("swa\.ldap\.1\.server.*", self.PI_OBJ.FQDN)
            fo.mstrtvarwoc("swa\.ldap\.1\.port.*", "389")
            
            fo.mstrtvarwoc("swa\.ldap\.2\.server.*", self.PI_OBJ.FQDN)
            fo.mstrtvarwoc("swa\.ldap\.2\.port.*", "389")
            
            fo.mstrtvarwoc("swa\.platform\.url.*", "http://" + self.PI_OBJ.FQDN + "/api")
            fo.mstrtvarwoc("swa\.platform\.url\.format.*", "")
            fo.mstrtvarwoc("swa\.platform\.enabled.*", "true")
            fo.mstrtvarwoc("swa\.soap\.soapRequestTimeout.*", "60")
            fo.write_wb()
        else:
            self.PI_OBJ._abort(_("STR_FILE") + ftt + _("STR_NOT_FOUND"))
            
        print "    OK"
        
    def _conf_sx_uberm(self):
        ftt = "/var/opt/scalix/" + self.PI_OBJ.SX_INSTANCE + "/caa/scalix.res/config/ubermanager.properties"
        if self.PI_OBJ._fe(ftt):
            fo = fileobj(ftt)
            fo.mstrtvarwoc("ubermanager\.query\.server.*", self.PI_OBJ.FQDN)
            fo.mstrtvarwoc("ubermanager\.kerberos\.mode.*", "false")
            fo.mstrtvarwoc("ubermanager\.kerberos\.principalName.*", "")
            fo.mstrtvarwoc("ubermanager\.kerberos\.kdc.*", "")
            fo.mstrtvarwoc("ubermanager\.kerberos\.realm.*", "")
            
            fo.mstrtvarwoc("ubermanager\.console\.externalAuth.*", "false")
            fo.mstrtvarwoc("ubermanager\.console\.allowExternalAuthChoice.*", "false")
            fo.mstrtvarwoc("ubermanager\.console\.maxListSize.*", "100")
            fo.mstrtvarwoc("ubermanager\.console\.localDomains.*", self.PI_OBJ.SX_UI_DOMAIN)
            fo.mstrtvarwoc("ubermanager\.console\.authDomains.*", "")
            fo.mstrtvarwoc("ubermanager\.console\.modifyExternalSyncedAuthId.*", "false")
            
            fo.mstrtvarwoc("ubermanager\.query\.server\.port.*", "389")
            fo.mstrtvarwoc("ubermanager\.configured.*", "true")
            fo.mstrtvarwoc("ubermanager\.version.*", self.PI_OBJ.SX_VERSION)
            fo.write_wb()
        else:
            self.PI_OBJ._abort(_("STR_FILE") + ftt + _("STR_NOT_FOUND"))
            
        ftc = "/var/opt/scalix/" + self.PI_OBJ.SX_INSTANCE + "/caa/scalix.res/config/psdata"
        fp = open(ftc, "w")
        fp.write(self.PI_OBJ.SX_UI_PASSWORD)
        fp.close()
        
        os.chown(ftc, 0, 0)
        os.chmod(ftc, 0400)
            
        print "    OK"
        
    def _conf_sx_res(self):
        ftt = "/var/opt/scalix/" + self.PI_OBJ.SX_INSTANCE + "/res/config/res.properties"
        if self.PI_OBJ._fe(ftt):
            fo = fileobj(ftt)
            fo.mstrtvarwoc("res\.kerberos\.mode.*", "")
            fo.mstrtvarwoc("res\.kerberos\.kdc.*", "")
            fo.mstrtvarwoc("res\.kerberos\.realm.*", "")
            fo.mstrtvarwoc("res\.kerberos\.allowedclients.*", "ubermanager/" + self.PI_OBJ.FQDN)
            
            fo.mstrtvarwoc("res\.ubermanager\.host.*", self.PI_OBJ.FQDN)
            fo.mstrtvarwoc("res\.tomcat\.tcp\.port.*", "80")
            fo.mstrtvarwoc("res\.configured.*", "true")
            fo.mstrtvarwoc("res\.version.*", self.PI_OBJ.SX_VERSION)
            fo.write_wb()
        else:
            self.PI_OBJ._abort(_("STR_FILE") + ftt + _("STR_NOT_FOUND"))
            
        print "    OK"
        
    def _conf_sx_messer(self):
        ftt = "/var/opt/scalix/" + self.PI_OBJ.SX_INSTANCE + "/platform/platform.properties"
        if self.PI_OBJ._fe(ftt):
            fo = fileobj(ftt)
            fo.mstrtvarwoc("imap\.host.*", self.PI_OBJ.FQDN)
            fo.mstrtvarwoc("smtp\.host.*", self.PI_OBJ.FQDN)
            fo.mstrtvarwoc("ldap\.port.*", "389")
            fo.mstrtvarwoc("hibernate\.connection\.url.*", "jdbc:postgresql://" + self.PI_OBJ.FQDN + ":5733/scalix")
            fo.mstrtvarwoc("hibernate\.connection\.password.*", self.PI_OBJ.SX_UI_PASSWORD)
            fo.write_wb()
        else:
            self.PI_OBJ._abort(_("STR_FILE") + ftt + _("STR_NOT_FOUND"))
            
        print "    OK"
        
    def _conf_sx_mobile(self):
        ftt = "/var/opt/scalix/" + self.PI_OBJ.SX_INSTANCE + "/mobile/mobile.properties"
        if self.PI_OBJ._fe(ftt):
            fo = fileobj(ftt)
            fo.mstrtvarwoc("platform\.url.*", "http://" + self.PI_OBJ.FQDN + "/api")
            fo.write_wb()
        else:
            self.PI_OBJ._abort(_("STR_FILE") + ftt + _("STR_NOT_FOUND"))
            
        print "    OK"
        
    def _conf_sx_search(self):
        ftt = "/var/opt/scalix/" + self.PI_OBJ.SX_INSTANCE + "/sis/sis.properties"
        if self.PI_OBJ._fe(ftt):
            fo = fileobj(ftt)
            fo.mstrtvarwoc("index\.language.*", "German")
            fo.mstrtvarwoc("index\.client\.whitelist.*", self.PI_OBJ.IP)
            fo.mstrtvarwoc("search\.client\.whitelist.*", self.PI_OBJ.IP)
            fo.write_wb()
        else:
            self.PI_OBJ._abort(_("STR_FILE") + ftt + _("STR_NOT_FOUND"))
            
        print "    OK"
        
    def _finish_inst(self):
        time.sleep(5)
        print "    " + _("INST_END_RESTART_TOMCAT")
        os.system("/etc/init.d/scalix-tomcat stop")
        time.sleep(3)
        os.system("/etc/init.d/scalix-tomcat start")
        
        print "    " + _("INST_END_COPY_APACHE_C")
        os.system("ln -s /opt/scalix/global/httpd/scalix-web-client.conf /etc/apache2/conf.d")
        
        ftt = "/etc/apache2/mods-enabled/proxy.conf"
        if self.PI_OBJ._fe(ftt):
            fo = fileobj(ftt)
            fo.rstrtvarwoc(".*Deny from.*", "                Deny from none")
            fo.rstrtvarwoc(".*#Allow from \.exa.*", "                Allow from all")
            fo.write_wb()
        else:
            self.PI_OBJ._abort(_("STR_FILE") + ftt + _("STR_NOT_FOUND"))
        
        print "    " + _("INST_END_JAVA_UTF8")
        ftt = "/opt/scalix-tomcat/bin/setclasspath.sh"
        if self.PI_OBJ._fe(ftt):
            fo = fileobj(ftt)
            fo.astrtfile("export LC_ALL=" + _("SX_CHARSET"))
            fo.astrtfile("export LANG=" + _("SX_CHARSET"))
            fo.write_wb()
        else:
            self.PI_OBJ._abort(_("STR_FILE") + ftt + _("STR_NOT_FOUND"))
            
        print "    " + _("INST_END_RESTART_APACHE")
        os.system("/etc/init.d/apache2 stop")
        time.sleep(3)
        os.system("/etc/init.d/apache2 start")
        
        print "    " + _("INST_END_INFO_1")
        print "    ---------------------------------------"
        print "    " + _("INST_END_INFO_2")
        print "    " + _("INST_END_INFO_3") + " http://" + self.PI_OBJ.IP + "/sac"
        print "    " + _("INST_END_INFO_4") + " http://" + self.PI_OBJ.IP + "/webmail"
        print ""
        print "    " + _("INST_END_INFO_5")
        print "    " + _("INST_END_INFO_6")
        print "    ---------------------------------------"